summaryrefslogtreecommitdiffstats
path: root/src/iteminterface.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/iteminterface.cpp')
-rw-r--r--src/iteminterface.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/iteminterface.cpp b/src/iteminterface.cpp
index 78bc7b0..6a60ec6 100644
--- a/src/iteminterface.cpp
+++ b/src/iteminterface.cpp
@@ -233,10 +233,10 @@ TQWidget * ItemInterface::configWidget()
VariantDataMap *variantMap = p_itemGroup->activeItem()->variantMap();
- TQWidget * tqparent = m_pActiveItemEditorToolBar;
+ TQWidget * parent = m_pActiveItemEditorToolBar;
- // Create new widget with the toolbar or dialog as the tqparent
- TQWidget * configWidget = new TQWidget( tqparent, "tbConfigWidget" );
+ // Create new widget with the toolbar or dialog as the parent
+ TQWidget * configWidget = new TQWidget( parent, "tbConfigWidget" );
configWidget->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding, 1, 1 ) );
TQHBoxLayout * configLayout = new TQHBoxLayout( configWidget );
@@ -385,8 +385,8 @@ TQWidget * ItemInterface::configWidget()
continue;
// In the case of the toolbar, we don't want it too high
- if ( editWidget->height() > tqparent->height()-2 )
- editWidget->setMaximumHeight( tqparent->height()-2 );
+ if ( editWidget->height() > parent->height()-2 )
+ editWidget->setMaximumHeight( parent->height()-2 );
switch ( type )
{